@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,11 +20,12 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 FormAlchemy Forms
 """
 
+from __future__ import unicode_literals
+
 from rattail.core import Object
 from pyramid.renderers import render
 from ..db import Session
@@ -40,7 +40,7 @@ class AlchemyForm(Object):
     """
 
     create_label = "Create"
-    update_label = "Update"
+    update_label = "Save"
 
     allow_successive_creates = False
 
