@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,11 +20,16 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 FormAlchemy Field Renderers
 """
 
-from .common import *
+from tailbone.forms.renderers.common import (
+    AutocompleteFieldRenderer,
+    DateTimeFieldRenderer,
+    EnumFieldRenderer,
+    YesNoFieldRenderer,
+    )
+
 from .people import *
 from .products import *
