@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,16 +20,17 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 Common Field Renderers
 """
 
+from __future__ import unicode_literals
+
+import formalchemy
 from formalchemy.fields import FieldRenderer, SelectFieldRenderer, CheckBoxFieldRenderer
 from pyramid.renderers import render
 
-
-__all__ = ['AutocompleteFieldRenderer', 'EnumFieldRenderer', 'YesNoFieldRenderer']
+from tailbone.util import pretty_datetime
 
 
 class AutocompleteFieldRenderer(FieldRenderer):
@@ -76,6 +76,26 @@ class AutocompleteFieldRenderer(FieldRenderer):
         return unicode(value)
 
 
+class DateTimeFieldRenderer(formalchemy.DateTimeFieldRenderer):
+    """
+    Custom date/time field renderer, which displays a "pretty" value in
+    read-only mode, leveraging config to show the correct timezone.
+    """
+
+    def __init__(self, config):
+        self.config = config
+
+    def __call__(self, field):
+        super(DateTimeFieldRenderer, self).__init__(field)
+        return self
+
+    def render_readonly(self, **kwargs):
+        value = self.raw_value
+        if not value:
+            return ''
+        return pretty_datetime(self.config, value)
+
+
 class EnumFieldRenderer(SelectFieldRenderer):
     """
     Renderer for simple enumeration fields.
