@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,18 +20,19 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 Template Context Helpers
 """
 
+from __future__ import unicode_literals
+
 import datetime
 from decimal import Decimal
 
 from webhelpers.html import *
 from webhelpers.html.tags import *
 
-from edbob.pyramid.forms import pretty_datetime
+from tailbone.util import pretty_datetime
 
 
 def pretty_date(date):
